@@ -1,22 +1,16 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[ ]:
-
-
-#!/usr/bin/env python
-# coding: utf-8
-
 # In[6]:
 
 
 
 HOST = ""
 PORT = 0
-ini = False
 
-def exec_and_return(expression):
-    exec(f"""globals()['temp'] = {expression}""")
+
+def exec_and_return(expression,scope):
+    exec(f"""globals()['temp'] = {expression}""",scope)
     return globals()['temp']
 
 
@@ -25,18 +19,23 @@ def init(_host,_port):
         global HOST
         global PORT
         global ini
+
         ini = True
 
         HOST = _host
         PORT = _port
+        
+       
 
    
     
-def start_server(debug = False):
+def start_server(scope,debug = False):
 
             import pickle, socket
             global HOST
             global PORT
+       
+            
             if ini == False:
                 
                 raise RuntimeError("Server not initialized, run remfunc.init(HOST,PORT) first. You only need to do this once.")
@@ -80,7 +79,7 @@ def start_server(debug = False):
                     result = None
                     try:
 
-                        result = exec_and_return(code)
+                        result = exec_and_return(code,scope)
 
                     except Exception as e:
 
@@ -128,6 +127,7 @@ def do(code):
             global HOST
             global PORT
             global ini
+            
            
                 
             if ini == False:
@@ -190,18 +190,6 @@ def do(code):
                     
                     
                     raise RuntimeError("Error recieving result")
-                    
-                
-
-
-# In[ ]:
-
-
-
-
-
-# In[ ]:
-
 
 
 
